from fastapi import APIRouter, Depends, status
from sqlalchemy.orm import Session
from core.database import get_db
from schemas.contact import ContactCreate, ContactSchema
from utils.contact_helpers import sanitize_contact_input, create_contact, format_contact_response

router = APIRouter()

@router.post("/contact", response_model=ContactSchema, status_code=status.HTTP_201_CREATED)
async def create_contact_submission(
    contact_data: ContactCreate,
    db: Session = Depends(get_db)
):
    sanitized_data = sanitize_contact_input(contact_data.dict())
    contact = create_contact(db=db, contact_data=ContactCreate(**sanitized_data))
    return format_contact_response(contact)